@@ -5,7 +5,6 @@ import os
 def setup_poetry(config):
     """Entry point of module: setup poetry files and run poetry commands"""
     update_pyproject_dot_toml(config)
-    install_poetry()
     #lock_poetry_dependencies()
     install_dependencies()
 
@@ -17,12 +16,7 @@ def lock_poetry_dependencies_on_docker():
 
 def install_dependencies():
     """Install package dependencies"""
-    os.system("poetry install")
-
-
-def install_poetry():
-    """Install poetry"""
-    os.system("pip install poetry")
+    os.system("pip install -r requirements.txt")
 
 
 def update_pyproject_dot_toml(config):
